body {
  margin: 0;
  color: #555;
  background-color: white;
  font-size: 85%;
  font-family: "Trebuchet MS",Verdana,Helvetica,Arial,sans-serif;
  background: white url("banner.jpg") repeat-x 0 0;
}

h1 {
  border-bottom: 1px solid #C90;
  color: #C90;
  font-size: 1.5em;
  text-align: left;
  width: 100%;
}

h2 {
  border-bottom: 1px dotted #ccc;
  color: #C90;
  font-size: 1.3em;
  width: 100%;
}

h3 {
  color: #555;
  font-size: 1.2em;
  width: 100%;
}

p {
  color: #555;
  font-size: 1em;
}

a:link,a:visited {
  border-bottom-style: dotted;
  border-bottom-width: 1px;
  color: #555;
  text-decoration: none;
}

a:hover {
  background-color: #fff;
  border-bottom-style: dotted;
  border-width: 0.1em;
  color: #C90;
}

img {
  border: none;
}

pre {
  background: #eee;
  border-bottom: 1px solid #ddd;
  border-top: 1px solid #ccc;
  color: #A90101;
  font-size: 1.1em;
  margin: 0.8em auto;
  padding: 1.6em 0.8em;
}

ul {
  color: #555;
  list-style-type: none;
  margin: 1.6em auto;
}

ul.simple {
  margin: 0;
  padding: 0;
}

li {
  left: 0;
  margin: 0 5em 0 0;
  padding: 0;
}

div#grokui-banner #logo span {
  display: none;
}

div#grokui-banner #logo {
  display: block;
  width: 164px;
  height: 81px;
  border: 0;
  text-decoration: none;
  background: transparent url("logo.gif") no-repeat 20px 0;
}

div#logout { 
  padding-right: 3em;
  background-color: #ddd;
  text-align: right;
  line-height: 28px;
  background: transparent url("shadow.jpg") repeat-x;
}

#grokui-menu-entries {
  text-align: center;
  margin: 0 0 1em 0;
}

#grokui-menu-entries li {
  display: inline;
  font-size: 1.1em;
}

#grokui-footer {
  text-align: center;
  border-top: 1px solid #ddd;
  margin-top: 2.5em;
  background-color: #f4f4f4;
}

#grokui-footer p {
  padding: 0.5em 0;
  margin: 0;
  color: #777;
}

div#grokui-content {
  padding: 0 5em;
}

div#grokui-messages {
  padding: 0 6em;
}

.messages-list {
  padding: 0;
}

#grokui-messages .message {
  padding: 0.1em 0.2em;
  color: #555;
  font-size: 1.1em;
  list-style-type: none;
  margin: 0;
}

form {
  clear: both;
}

input, select {
  border: 1px solid #C90;
  margin: 0;
  padding: 0;
}

.button {
  background-color: #ccc;
  font-size: 1em;
  padding: 0;
  margin: 0;
}

fieldset {
  position: relative;
  margin-top: 1em;
  padding: 1.2em 0.8em;
  border: 1px solid #c90;
  text-align: left;
  background-color: #f9f9D4;
  border-radius : 10px;
  -moz-border-radius : 10px;
  -webkit-border-radius : 10px;
}

fieldset fieldset {
  border: 0;
  margin: 0 1em;
  background-color: transparent;
}

legend {
  color: #c90;
  font-size: 1.2em;
  font-weight: 700;
  background-color: transparent;
}

a.button {
  color: #000;
  padding: 0 0.2em 0.2em;
}

a:hover.button {
  background-color: #ccc;
  color: #000;
  padding: 0 0.2em 0.2em;
}

dl.table {
  margin: 1em;
}

dl.table dt {
  border: 1px solid #cc9900;
  margin-left: 0;
  margin-top: 0.5em;
  padding-left: 0.75em;
  background-color: #fff4be;
  font-weight: bold;
}

dl.table dd {
  border: 1px solid #cc9900;
  border-top: none;
  margin: 0 0 1em 0;
  padding-left: 0.75em;
  background-color: white;
}

.details {
  margin: 0 0.75em;
}

.details .description {
  font-size: 90%;
  margin: 0.2em 0;
}

.details h3 {
  margin: 0.2em 0 0.1em 0;
  font-size: 130%;
  border-bottom: 1px solid #cc9900;
  padding: 0;
}

label {
  font-weight: bold !important;
}
